@@ -16,7 +16,7 @@ import sys
 from enlighten._counter import Counter as _Counter
 from enlighten._counter import SubCounter  # pylint: disable=unused-import # noqa: F401
 from enlighten._statusbar import StatusBar  # pylint: disable=unused-import # noqa: F401
-from enlighten._manager import get_manager
+from enlighten.manager import get_manager
 
 
 # Counter is defined here to avoid circular dependencies
